"""Auto-assessment library for Python"""

from .annotations import *
from .execution import *
from .reference import *
from .student import *
from .version import __version__
